crikit.preprocess.tests package — CRIKit2 0.4.3 documentation

# crikit.preprocess.tests package

## Submodules

## crikit.preprocess.tests.test_als module

Testing the aysmmetric least-squares detrending algorithm

crikit.preprocess.tests.test_als.test_2Dbasic_redux_rng()

crikit.preprocess.tests.test_als.test_basic()

crikit.preprocess.tests.test_als.test_basic_redux()

crikit.preprocess.tests.test_als.test_basic_redux_rng()

crikit.preprocess.tests.test_als.test_basic_rng()

crikit.preprocess.tests.test_als.test_fix_ends()

crikit.preprocess.tests.test_als.test_fix_rng()

crikit.preprocess.tests.test_als.test_rng_redux_fix_rng()

crikit.preprocess.tests.test_als.test_rng_redux_fix_rng_vecasym()

crikit.preprocess.tests.test_als.test_vec_asym_param()

crikit.preprocess.tests.test_als.test_vec_asym_param_rng_redux()

## crikit.preprocess.tests.test_anscombe module

crikit.preprocess.tests.test_anscombe.make_datasets()

  Setups and tears down a series of datasets

crikit.preprocess.tests.test_anscombe.test_calc_ansc_params(make_datasets)

  Calculate Anscombe Parameters

## crikit.preprocess.tests.test_baseline_sub module

Testing the aysmmetric least-squares detrending algorithm

crikit.preprocess.tests.test_baseline_sub.test_2Dbasic_redux_rng()

crikit.preprocess.tests.test_baseline_sub.test_2Dbasic_transform_redux_rng()

crikit.preprocess.tests.test_baseline_sub.test_basic()

crikit.preprocess.tests.test_baseline_sub.test_basic_redux()

crikit.preprocess.tests.test_baseline_sub.test_basic_redux_rng()

crikit.preprocess.tests.test_baseline_sub.test_basic_rng()

crikit.preprocess.tests.test_baseline_sub.test_fix_ends()

crikit.preprocess.tests.test_baseline_sub.test_fix_rng()

crikit.preprocess.tests.test_baseline_sub.test_rng_redux_fix_rng()

crikit.preprocess.tests.test_baseline_sub.test_vec_asym_param()

crikit.preprocess.tests.test_baseline_sub.test_vec_asym_param_rng_redux()

## crikit.preprocess.tests.test_crop module

crikit.preprocess.tests.test_crop.test_cut_every_n_spectra()

crikit.preprocess.tests.test_crop.test_zero_col_first_col()

crikit.preprocess.tests.test_crop.test_zero_col_last_col()

crikit.preprocess.tests.test_crop.test_zero_row_first_row()

crikit.preprocess.tests.test_crop.test_zero_row_last_row()

## crikit.preprocess.tests.test_subtract_dark module

crikit.preprocess.tests.test_subtract_dark.make_datasets()

  Setups and tears down a series of datasets

crikit.preprocess.tests.test_subtract_dark.test_sub_hsi_from_hsi(make_datasets)

  Dark is HSI. Data is HSI.

crikit.preprocess.tests.test_subtract_dark.test_sub_hsi_from_spectra(make_datasets)

  Dark is HSI. Data is spectrum.

crikit.preprocess.tests.test_subtract_dark.test_sub_hsi_from_spectrum(make_datasets)

  Dark is HSI. Data is spectrum.

crikit.preprocess.tests.test_subtract_dark.test_sub_hsi_int_from_hsi_float(make_datasets)

  Dark is HSI. Data is HSI.

crikit.preprocess.tests.test_subtract_dark.test_sub_spectra_from_hsi(make_datasets)

  Dark is spectra. Data is HSI.

crikit.preprocess.tests.test_subtract_dark.test_sub_spectra_from_spectra(make_datasets)

  Dark is spectra. Data is spectra.

crikit.preprocess.tests.test_subtract_dark.test_sub_spectra_from_spectrum(make_datasets)

  Dark is spectra. Data is spectrum.

crikit.preprocess.tests.test_subtract_dark.test_sub_spectrum_from_hsi(make_datasets)

  Dark is spectrum. Data is HSI.

crikit.preprocess.tests.test_subtract_dark.test_sub_spectrum_from_spectra(make_datasets)

  Dark is spectrum. Data is spectra.

crikit.preprocess.tests.test_subtract_dark.test_sub_spectrum_from_spectrum(make_datasets)

  Dark is spectrum. Data is spectrum.

crikit.preprocess.tests.test_subtract_dark.test_transform_incompatible_dtypes(make_datasets)

  Test that TypeError is raised when Dark and Data have incompatible dtypes for in-place transformation

  Note: if spectra or hsi is used for dark, will convert to float due to mean

## Module contents